==> deepin-app-store_5.6.3.9.orig.tar.xz: deepin-app-store-5.6.3.9/translations/deepin-app-store_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="235"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="41"/>
        <source>Clear cache</source>
        <translation>Neteja la memòria cau</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="44"/>
        <source>Privacy Policy</source>
        <translation>Política de privadesa</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Refés</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Retalla</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Selecciona-ho tot</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="115"/>
        <source>App Store</source>
        <translation>Botiga d&apos;aplicacions</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="116"/>
        <source>App Store is a software center with diverse and quality applications, supporting installation and uninstallation with one click.</source>
        <translation>La Botiga d&apos;aplicacions és un centre de programari amb una diversitat d&apos;aplicacions de qualitat que admet la instal·lació i la desinstal·lació amb un sol clic.</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <source>Search for &quot;%1&quot; in Store</source>
        <translation>Cerca &quot;%1&quot; a la botiga</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Store</source>
        <translation>Cerca &quot;%1&quot; a la botiga.</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Els meus comentaris</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Les meves aplicacions</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Surt</translation>
    </message>
</context>
</TS>

==> deepin-app-store_6.2.0.30.orig.tar.xz: deepin-app-store-6.2.0.30/translations/deepin-app-store_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="250"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="43"/>
        <source>Clear cache</source>
        <translation>Neteja la memòria cau</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="vanished">Política de privadesa</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Refés</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Retalla</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Selecciona-ho tot</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="61"/>
        <source>App Store</source>
        <translation>Botiga d&apos;aplicacions</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="62"/>
        <source>App Store is a software center with diverse and quality applications, supporting installation and uninstallation with one click.</source>
        <translation>La Botiga d&apos;aplicacions és un centre de programari amb una diversitat d&apos;aplicacions de qualitat que admet la instal·lació i la desinstal·lació amb un sol clic.</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="71"/>
        <location filename="../src/app/deepin_app_store.cpp" line="73"/>
        <source>UnionTech Software Privacy Policy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <source>Search for &quot;%1&quot; in Store</source>
        <translation>Cerca &quot;%1&quot; a la botiga</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Store</source>
        <translation>Cerca &quot;%1&quot; a la botiga.</translation>
    </message>
</context>
<context>
    <name>dstore::AccountProxy</name>
    <message>
        <location filename="../src/ui/channel/account_proxy.cpp" line="35"/>
        <source>Activate</source>
        <translation>Activa&apos;l</translation>
    </message>
    <message>
        <location filename="../src/ui/channel/account_proxy.cpp" line="44"/>
        <source>Your system is not activated. Please activate as soon as possible for normal use.</source>
        <translation>El sistema no està activat. Si us plau, activeu-lo al més aviat possible per usar-lo normalment.</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Els meus comentaris</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Les meves aplicacions</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Surt</translation>
    </message>
</context>
</TS>
